@@ -1,5 +1,4 @@
 use crate::web::{Method, Request, Response};
-use serde_json::Value;
 use std::collections::HashMap;
 use web_sys::Url;
 
@@ -20,7 +19,7 @@ pub struct Conn {
     pub resp_headers: HashMap<String, String>,
     pub status: u16,
     // Connection
-    pub assigns: HashMap<String, Value>,
+    pub assigns: HashMap<String, String>,
     pub params: HashMap<String, String>,
     pub halted: bool,
 }
@@ -95,6 +94,7 @@ pub fn redirect_to(conn: Conn, to: &str) -> Conn {
         resp_headers: headers,
         resp_body: "".to_string(),
         status: 302,
+        halted: true,
         ..conn
     };
 }
