@@ -42,9 +42,24 @@ pub async fn get_session_id_conn(conn: Conn) -> Conn {
             }
             return add_new_session(conn);
         }
-        None => {
-            return add_new_session(conn);
-        }
+        None => match conn.req_headers.get("authorization") {
+            Some(authorization) => {
+                if authorization.starts_with("Bearer") || authorization.starts_with("bearer") {
+                    let v: Vec<&str> = authorization.split(" ").collect();
+                    let mut assigns: HashMap<String, String> = conn.assigns.clone();
+                    assigns.insert("session_id".to_owned(), v[1].to_owned());
+                    return Conn {
+                        assigns: assigns,
+                        ..conn
+                    };
+                } else {
+                    return add_new_session(conn);
+                }
+            }
+            None => {
+                return add_new_session(conn);
+            }
+        },
     };
 }
 
@@ -61,7 +76,8 @@ fn add_new_session(conn: Conn) -> Conn {
     let mut resp_headers: HashMap<String, String> = conn.resp_headers.clone();
     resp_headers.insert(
         "Set-Cookie".to_owned(),
-        format!("confetti_session_id={};", session_id),
+        // Max Age - 5 days
+        format!("confetti_session_id={}; Max-Age=432000", session_id),
     );
     return Conn {
         assigns: assigns,
